@@ -3,6 +3,10 @@ import json
 import pyspark.sql.functions as F
 from pyspark.sql import DataFrame
 
+from data_product_sdk.cortex_databricks.data_platform.spark_utils import (
+    get_spark_session
+)
+
 
 def calculate_profilling(df: DataFrame, layer: str):
     df_count = df.count()
@@ -288,3 +292,26 @@ def _treat_most_frequent_fields(df: DataFrame, limit=30):
                 "count": row_json["count"]
             })
     return fields
+
+
+def get_volumetry(catalog, stage, table_name, df: DataFrame, spark=None):
+    if spark is None:
+        spark = get_spark_session("upsert_data")
+    table = spark.sql(f""" SELECT * FROM  {catalog}.{stage}.{table_name} """)
+    
+    return table.count() + df.count()
+
+def get_details(catalog, stage, table_name, spark=None):
+    if spark is None:
+        spark = get_spark_session("upsert_data")
+    df_details = spark.sql(f""" DESCRIBE DETAIL {catalog}.{stage}.{table_name} """)
+    temp_list = df_details.select("lastModified", "createdAt").collect()
+    last_update = temp_list[0][0]
+    create_date = temp_list[0][1]
+    return last_update, create_date
+
+def get_rows_count(df : DataFrame):
+    return df.count()
+
+def get_columns_count(df : DataFrame):
+    return len(df.columns)
